@@ -98,6 +98,10 @@ class VolumeDeviceNotFound(BrickException):
     message = _("Volume device not found at %(device)s.")
 
 
+class VolumePathsNotFound(BrickException):
+    message = _("Could not find any paths for the volume.")
+
+
 class VolumePathNotRemoved(BrickException):
     message = _("Volume path %(volume_path)s was not removed in time.")
 
@@ -108,3 +112,23 @@ class ProtocolNotSupported(BrickException):
 
 class TargetPortalNotFound(BrickException):
     message = _("Unable to find target portal %(target_portal)s.")
+
+
+class FailedISCSITargetPortalLogin(BrickException):
+    message = _("Unable to login to iSCSI Target Portal")
+
+
+class BlockDeviceReadOnly(BrickException):
+    message = _("Block device %(device)s is Read-Only.")
+
+
+class VolumeGroupNotFound(BrickException):
+    message = _("Unable to find Volume Group: %(vg_name)s")
+
+
+class VolumeGroupCreationFailed(BrickException):
+    message = _("Failed to create Volume Group: %(vg_name)s")
+
+
+class CommandExecutionFailed(BrickException):
+    message = _("Failed to execute command %(cmd)s")
